==> driza-unix-0.1.tar.gz: driza-unix-0.1/src/driza.py <==
#!/usr/bin/python
# -*- coding: latin-1 -*-
###################################
#
#  DRIZA
#
###################################


#Copyright (C) 2006  Nstor Arocha Rodrguez

#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.

#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.

#You should have received a copy of the GNU General Public License along
#with this program; if not, write to the Free Software Foundation, Inc.,
#51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

VERSION="0.1"


#Imports
#Librerias del sistema
import sys

#Librerias del programa
import datos
import config
import interfaz
#Directorio de ventanas y dilogos
sys.path.append("./dialog/")
from vprincipal import VPrincipal
from vsalida import VSalida
from dsplash import DSplash
from qt import *

class Driza(QApplication):
	"""Clase - aplicacin principal. 
	El widget principal es Vprincipal, que es el dialogo principal
	"""
	def __init__(self,args,config):
		""" Constructor de la clase general
		Recibe la configuracin, e inicializa las variables
		"""
		QApplication.__init__(self,args)
		
		#La configuracion. Se espera un ConfigHandler
		self.config=config
		#Datos es el objeto que guarda los datos
		self.dato=datos.contenedorregvar()
		#Se espera el objeto variable que actua como filtro
		self.filtro=None
		
		#Inicializacin de interfaces. Actuan como elementos conversores
		self.ifi=interfaz.IFile(self.config,self.dato)
		self.isa=interfaz.IOutput(self.config,self.dato)

		# Inicializacin de ventanas
		self.maindialog = VPrincipal(self)
		self.vsalida = VSalida()
		self.splash = DSplash(self.maindialog,"Dialogo Splash",0,)
		self.setMainWidget(self.maindialog)

	def bucle(self):
		""" Procedimiento Bucle principal. 
		Lanzamos la ventana splash despues de la principal para que obtenga el foco"""
		self.maindialog.show()
		self.splash.show()
		self.exec_loop() 

	def cargarfichero(self,filename):
		"""Funcion de carga de ficheros. A partir del nombre de fichero carga el dato y manda la orden de refresco a las ventanas miembro"""
		self.dato=self.ifi.imp(filename) #
		self.config["lfichero"].append(filename)
		self.maindialog.show()
	
	def guardarfichero(self,filename):
		"""Realiza la accion de guardar los datos en filename"""
		self.ifi.exp(filename)

	def calcular(self,accion,variables,opciones):
		"""Esta funcion recibe del dialogo de calculo los datos necesarios y una vez calculados los importa a la salida
		-accion es una cadena con el nombre de la accion
		-variables es una lista con el nombre de las variables
		-opciones es un diccionario con las opciones
		"""
		objeto=self.isa.exp(accion,variables,opciones)
		self.vsalida.app_obj(objeto) #Aadir a la salida el resultado
		self.vsalida.show()

	def crearvariable(self,nombre=None,cadena=None):
		"""Crea la variable nombre a partir de la expresin cadena
		Si no se pasa cadena, se crea una variable con los valores por defecto
		"""
		if not cadena:
			#Creamos una variable con los valores por defecto
			self.dato.app_var()
		else:
			#Trabajamos para crear una variable a partir de una expresion
			self.dato.app_var(nombre,"I",0)
			#transformar expresion para que "pille" las variables
			for var in self.dato.vars:
				#sustituir en la cadena
				numero=self.dato.mat_var(var)
				cadena=cadena.replace(var.nombre,"self.dato.get_cel(i,"+repr(numero)+")")
			for i in range(self.dato.num_dat()):
				self.dato[i].append(eval(cadena)) #Problema: el eval trabaja con strings, y al sumar suma strings
			self.maindialog.show()
	

if __name__ == "__main__":

	#Obtencin de parametros de ejecucion
	#sys.argv ... pendiente

	#Creacion del objetos. 
	# Pendiente mover estos objetos dentro de la ventana principal, o solo pasar el nombre
	conf=config.ConfigHandler()

	#Creacion de la interfaz de usuario y Llamada al loop de QT

	ventanaprincipal=Driza(sys.argv,conf)
	ventanaprincipal.bucle()

==> driza-unix-0.2.tar.gz: driza-unix-0.2/src/driza.py <==
#!/usr/bin/python
# -*- coding: latin-1 -*-
###################################
#
#  DRIZA
#
###################################


#Copyright (C) 2006  Inmaculada Luengo Merino, Nstor Arocha Rodrguez

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

VERSION="0.2"


#Imports
#Librerias del sistema
import sys

#Librerias del programa
import datos
import config
import interfaz
#Directorio de ventanas y dilogos
sys.path.append("./dialog/vprincipal")
from vprincipal import VPrincipal
from vsalida import VSalida
from dsplash import DSplash
from qt import *

class Driza(QApplication):
	"""Clase - aplicacin principal. 
	El widget principal es Vprincipal, que es el dialogo principal
	"""
	def __init__(self,args,config):
		""" Constructor de la clase general
		Recibe la configuracin, e inicializa las variables
		"""
		QApplication.__init__(self,args)
		
		#La configuracion. Se espera un ConfigHandler
		self.config=config
		#Datos es el objeto que guarda los datos
		self.dato=datos.contenedorregvar()
		#Se espera el objeto variable que actua como filtro
		self.filtro=None
		
		#Inicializacin de interfaces. Actuan como elementos conversores
		self.ifi=interfaz.IFile(self.config,self.dato)
		self.isa=interfaz.IOutput(self.config,self.dato)

		# Inicializacin de ventanas
		self.maindialog = VPrincipal(self)
		self.vsalida = VSalida()
		self.splash = DSplash(self.maindialog,"Dialogo Splash",0,)
		self.setMainWidget(self.maindialog)

	def bucle(self):
		""" Procedimiento Bucle principal. 
		Lanzamos la ventana splash despues de la principal para que obtenga el foco"""
		self.maindialog.show()
		if self.config["vsplash"]:
			#El usuario quiere ver la ventana splash
			self.splash.show()
		if self.config.new:
			#Es la primera vez que se ejecuta el programa
			rc = QMessageBox.information(self.maindialog,'Bienvenido', 'Parece que es la primera vez que ejecutas driza')
		self.exec_loop() 

	def cargarfichero(self,filename):
		"""Funcion de carga de ficheros. A partir del nombre de fichero carga el dato y manda la orden de refresco a las ventanas miembro"""
		self.dato=self.ifi.imp(filename) #
		self.config["lfichero"].append(filename)
		self.maindialog.show()
	
	def guardarfichero(self,filename):
		"""Realiza la accion de guardar los datos en filename"""
		self.ifi.exp(filename)

	def calcular(self,accion,variables,opciones):
		"""Esta funcion recibe del dialogo de calculo los datos necesarios y una vez calculados los importa a la salida
		-accion es una cadena con el nombre de la accion
		-variables es una lista con el nombre de las variables
		-opciones es un diccionario con las opciones
		"""
		objeto=self.isa.exp(accion,variables,opciones)
		self.vsalida.app_obj(objeto) #Aadir a la salida el resultado
		self.vsalida.show()

	def crearvariable(self,nombre=None,cadena=None):
		"""Crea la variable nombre a partir de la expresin cadena
		Si no se pasa cadena, se crea una variable con los valores por defecto
		"""
		if not cadena:
			#Creamos una variable con los valores por defecto
			self.dato.app_var()
		else:
			#Trabajamos para crear una variable a partir de una expresion
			self.dato.app_var(nombre,"I",0)
			#transformar expresion para que "pille" las variables
			for var in self.dato.vars:
				#sustituir en la cadena
				numero=self.dato.mat_var(var)
				cadena=cadena.replace(var.nombre,"self.dato.get_cel(i,"+repr(numero)+")")
			for i in range(self.dato.num_dat()):
				self.dato[i].append(eval(cadena)) #Problema: el eval trabaja con strings, y al sumar suma strings
			self.maindialog.show()
	

if __name__ == "__main__":

	#Obtencin de parametros de ejecucion
	#sys.argv ... pendiente

	#Creacion del objetos. 
	conf=config.ConfigHandler()

	#Creacion de la interfaz de usuario y Llamada al loop de QT
	ventanaprincipal=Driza(sys.argv,conf)
	ventanaprincipal.bucle()
